==> testrepo44-0.0.0.tar.gz: testrepo44-0.0.0/README.md <==
<div align="center"><!-- ------------------------- START : Logo ------------------------- -->
<a href="https://aariam.github.io/testrepo44"><picture><source media="(prefers-color-scheme: dark)" srcset=".meta/ui/logo/full_dark.svg"><source media="(prefers-color-scheme: light)" srcset=".meta/ui/logo/full_light.svg"><img alt="testrepo44: Python Projects Perfected: Innovate, Develop, and Deploy " title="Welcome to testrepo44! Click to visit our website and learn more." width="80%" height="auto" align="center" src=".meta/ui/logo/full_light.svg"></picture></a>
<!-- ------------------------- END : Logo ------------------------- -->
<!-- ------------------------- START : Top Panel ------------------------- -->
<div align="center"><hr width="80%">
<a href="https://aariam.github.io/testrepo44/intro/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Intro&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Intro&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
		<img alt="Intro" title="Intro" height="35px" src="https://img.shields.io/static/v1?label=&message=Intro&style=for-the-badge&color=135400">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/testrepo44/manual/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Manual&style=for-the-badge&color=4EA020" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Manual&style=for-the-badge&color=115300" media="(prefers-color-scheme: light)">
		<img alt="Manual" title="Manual" height="35px" src="https://img.shields.io/static/v1?label=&message=Manual&style=for-the-badge&color=115300">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/testrepo44/api/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=API&style=for-the-badge&color=58A51C" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=API&style=for-the-badge&color=0F5301" media="(prefers-color-scheme: light)">
		<img alt="API" title="API" height="35px" src="https://img.shields.io/static/v1?label=&message=API&style=for-the-badge&color=0F5301">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/testrepo44/news/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=News&style=for-the-badge&color=62AB18" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=News&style=for-the-badge&color=0E5201" media="(prefers-color-scheme: light)">
		<img alt="News" title="News" height="35px" src="https://img.shields.io/static/v1?label=&message=News&style=for-the-badge&color=0E5201">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/testrepo44/contribute/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Contribute&style=for-the-badge&color=6BB014" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Contribute&style=for-the-badge&color=0C5202" media="(prefers-color-scheme: light)">
		<img alt="Contribute" title="Contribute" height="35px" src="https://img.shields.io/static/v1?label=&message=Contribute&style=for-the-badge&color=0C5202">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/testrepo44/about/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=About&style=for-the-badge&color=75B610" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=About&style=for-the-badge&color=0B5102" media="(prefers-color-scheme: light)">
		<img alt="About" title="About" height="35px" src="https://img.shields.io/static/v1?label=&message=About&style=for-the-badge&color=0B5102">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/testrepo44/help/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Help&style=for-the-badge&color=7FBB0C" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Help&style=for-the-badge&color=095103" media="(prefers-color-scheme: light)">
		<img alt="Help" title="Help" height="35px" src="https://img.shields.io/static/v1?label=&message=Help&style=for-the-badge&color=095103">
	</picture>
</a>
<hr width="100%"></div>
<!-- ------------------------- END : Top Panel ------------------------- -->
<!-- ------------------------- START : Description ------------------------- -->
<p align="justify">PyPackIT is a free and open-source toolkit <b>empowering the development of open-source Python projects on GitHub</b>. It is a <b>dynamic repository template</b> that provides a complete, professional, and robust infrastructure for your project, where the only thing missing is your code. With PyPackIT, you can solely focus on what truly matters: implementing your ideas and bringing your vision to life!</p>
<picture>
	<source srcset="https://img.shields.io/static/v1?label=&message=Automation&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
	<source srcset="https://img.shields.io/static/v1?label=&message=Automation&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
	<img alt="Automation" title="Automation" height="35px" src="https://img.shields.io/static/v1?label=&message=Automation&style=for-the-badge&color=135400">
</picture>
<p align="justify">PyPackIT streamlines a remarkable portion of the process of creating, documenting, testing, publishing, and maintaining Python packages, making your project development a pleasant breeze!</p>
<picture>
	<source srcset="https://img.shields.io/static/v1?label=&message=Synchronization&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
	<source srcset="https://img.shields.io/static/v1?label=&message=Synchronization&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
	<img alt="Synchronization" title="Synchronization" height="35px" src="https://img.shields.io/static/v1?label=&message=Synchronization&style=for-the-badge&color=135400">
</picture>
<p align="justify">PyPackIT gathers all your project's key information and configuration in one place, and dynamically updates them throughout your repository, Python package, and documentation website.</p>
<picture>
	<source srcset="https://img.shields.io/static/v1?label=&message=Configuration&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
	<source srcset="https://img.shields.io/static/v1?label=&message=Configuration&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
	<img alt="Configuration" title="Configuration" height="35px" src="https://img.shields.io/static/v1?label=&message=Configuration&style=for-the-badge&color=135400">
</picture>
<p align="justify">PyPackIT elevates your project by providing full configuration for your repository, Python package, and documentation website, according to the latest guidelines and best practices.</p>
<picture>
	<source srcset="https://img.shields.io/static/v1?label=&message=Customization&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
	<source srcset="https://img.shields.io/static/v1?label=&message=Customization&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
	<img alt="Customization" title="Customization" height="35px" src="https://img.shields.io/static/v1?label=&message=Customization&style=for-the-badge&color=135400">
</picture>
<p align="justify">While carefully configured, PyPackIT is also fully customizable, allowing you to tailor every aspect of your development pipeline to your specific needs</p>
<picture>
	<source srcset="https://img.shields.io/static/v1?label=&message=Documentation&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
	<source srcset="https://img.shields.io/static/v1?label=&message=Documentation&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
	<img alt="Documentation" title="Documentation" height="35px" src="https://img.shields.io/static/v1?label=&message=Documentation&style=for-the-badge&color=135400">
</picture>
<p align="justify">PyPackIT comes with a professional website for your project, that is easily customizable, and automatically generated and deployed on your preferred platform.</p>
<picture>
	<source srcset="https://img.shields.io/static/v1?label=&message=Production&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
	<source srcset="https://img.shields.io/static/v1?label=&message=Production&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
	<img alt="Production" title="Production" height="35px" src="https://img.shields.io/static/v1?label=&message=Production&style=for-the-badge&color=135400">
</picture>
<p align="justify">With PyPackIT, the only remaining step to publishing a production-ready Python project is adding your code, unit-tests and documentation content.</p>
<!-- ------------------------- END : Description ------------------------- -->
<!-- ------------------------- START : Bottom Panel ------------------------- -->
<div align="center"><hr width="100%">
<a href="https://aariam.github.io/testrepo44/manual/install">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Install&style=for-the-badge&color=88C108" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Install&style=for-the-badge&color=085003" media="(prefers-color-scheme: light)">
		<img alt="Install" title="Install" height="35px" src="https://img.shields.io/static/v1?label=&message=Install&style=for-the-badge&color=085003">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/testrepo44/news/category/release">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Releases&style=for-the-badge&color=92C604" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Releases&style=for-the-badge&color=065004" media="(prefers-color-scheme: light)">
		<img alt="Releases" title="Releases" height="35px" src="https://img.shields.io/static/v1?label=&message=Releases&style=for-the-badge&color=065004">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/testrepo44/help/ask">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Q%26A&style=for-the-badge&color=9CCC00" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Q%26A&style=for-the-badge&color=055005" media="(prefers-color-scheme: light)">
		<img alt="Q&A" title="Q&A" height="35px" src="https://img.shields.io/static/v1?label=&message=Q%26A&style=for-the-badge&color=055005">
	</picture>
</a>
<hr width="80%"></div>
<!-- ------------------------- END : Bottom Panel ------------------------- --></div>

==> testrepo123-0.0.0.tar.gz: testrepo123-0.0.0/README.md <==
<div align="center"><!-- ------------------------- START : Logo ------------------------- -->
<a href="https://aariam.github.io/TestRepo123"><picture><source media="(prefers-color-scheme: dark)" srcset=".meta/ui/logo/full_dark.svg"><source media="(prefers-color-scheme: light)" srcset=".meta/ui/logo/full_light.svg"><img alt="TestRepo123: YOUR Tag HERE" title="Welcome to TestRepo123! Click to visit our website and learn more." width="80%" height="auto" align="center" src=".meta/ui/logo/full_light.svg"></picture></a>
<!-- ------------------------- END : Logo ------------------------- -->
<!-- ------------------------- START : Top Panel ------------------------- -->
<div align="center"><hr width="80%">
<a href="https://aariam.github.io/TestRepo123/intro/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Intro&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Intro&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
		<img alt="Intro" title="Intro" height="35px" src="https://img.shields.io/static/v1?label=&message=Intro&style=for-the-badge&color=135400">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/TestRepo123/manual/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Manual&style=for-the-badge&color=4EA020" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Manual&style=for-the-badge&color=115300" media="(prefers-color-scheme: light)">
		<img alt="Manual" title="Manual" height="35px" src="https://img.shields.io/static/v1?label=&message=Manual&style=for-the-badge&color=115300">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/TestRepo123/api/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=API&style=for-the-badge&color=58A51C" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=API&style=for-the-badge&color=0F5301" media="(prefers-color-scheme: light)">
		<img alt="API" title="API" height="35px" src="https://img.shields.io/static/v1?label=&message=API&style=for-the-badge&color=0F5301">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/TestRepo123/news/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=News&style=for-the-badge&color=62AB18" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=News&style=for-the-badge&color=0E5201" media="(prefers-color-scheme: light)">
		<img alt="News" title="News" height="35px" src="https://img.shields.io/static/v1?label=&message=News&style=for-the-badge&color=0E5201">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/TestRepo123/contribute/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Contribute&style=for-the-badge&color=6BB014" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Contribute&style=for-the-badge&color=0C5202" media="(prefers-color-scheme: light)">
		<img alt="Contribute" title="Contribute" height="35px" src="https://img.shields.io/static/v1?label=&message=Contribute&style=for-the-badge&color=0C5202">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/TestRepo123/about/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=About&style=for-the-badge&color=75B610" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=About&style=for-the-badge&color=0B5102" media="(prefers-color-scheme: light)">
		<img alt="About" title="About" height="35px" src="https://img.shields.io/static/v1?label=&message=About&style=for-the-badge&color=0B5102">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/TestRepo123/help/index">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Help&style=for-the-badge&color=7FBB0C" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Help&style=for-the-badge&color=095103" media="(prefers-color-scheme: light)">
		<img alt="Help" title="Help" height="35px" src="https://img.shields.io/static/v1?label=&message=Help&style=for-the-badge&color=095103">
	</picture>
</a>
<hr width="100%"></div>
<!-- ------------------------- END : Top Panel ------------------------- -->
<!-- ------------------------- START : Description ------------------------- -->
<p align="justify">YOUR DESCRIPTION HERE</p>
<picture>
	<source srcset="https://img.shields.io/static/v1?label=&message=FIRST%20KEYNOTE%20TITLE&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
	<source srcset="https://img.shields.io/static/v1?label=&message=FIRST%20KEYNOTE%20TITLE&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
	<img alt="FIRST KEYNOTE TITLE" title="FIRST KEYNOTE TITLE" height="35px" src="https://img.shields.io/static/v1?label=&message=FIRST%20KEYNOTE%20TITLE&style=for-the-badge&color=135400">
</picture>
<p align="justify">FIRST KEYNOTE DESCRIPTION</p>
<picture>
	<source srcset="https://img.shields.io/static/v1?label=&message=SECOND%20KEYNOTE%20TITLE&style=for-the-badge&color=459B24" media="(prefers-color-scheme: dark)">
	<source srcset="https://img.shields.io/static/v1?label=&message=SECOND%20KEYNOTE%20TITLE&style=for-the-badge&color=135400" media="(prefers-color-scheme: light)">
	<img alt="SECOND KEYNOTE TITLE" title="SECOND KEYNOTE TITLE" height="35px" src="https://img.shields.io/static/v1?label=&message=SECOND%20KEYNOTE%20TITLE&style=for-the-badge&color=135400">
</picture>
<p align="justify">SECOND KEYNOTE DESCRIPTION</p>
<!-- ------------------------- END : Description ------------------------- -->
<!-- ------------------------- START : Bottom Panel ------------------------- -->
<div align="center"><hr width="100%">
<a href="https://aariam.github.io/TestRepo123/manual/install">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Install&style=for-the-badge&color=88C108" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Install&style=for-the-badge&color=085003" media="(prefers-color-scheme: light)">
		<img alt="Install" title="Install" height="35px" src="https://img.shields.io/static/v1?label=&message=Install&style=for-the-badge&color=085003">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/TestRepo123/news/category/release">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Releases&style=for-the-badge&color=92C604" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Releases&style=for-the-badge&color=065004" media="(prefers-color-scheme: light)">
		<img alt="Releases" title="Releases" height="35px" src="https://img.shields.io/static/v1?label=&message=Releases&style=for-the-badge&color=065004">
	</picture>
</a>&nbsp;&nbsp; <a href="https://aariam.github.io/TestRepo123/help/ask">
	<picture>
		<source srcset="https://img.shields.io/static/v1?label=&message=Q%26A&style=for-the-badge&color=9CCC00" media="(prefers-color-scheme: dark)">
		<source srcset="https://img.shields.io/static/v1?label=&message=Q%26A&style=for-the-badge&color=055005" media="(prefers-color-scheme: light)">
		<img alt="Q&A" title="Q&A" height="35px" src="https://img.shields.io/static/v1?label=&message=Q%26A&style=for-the-badge&color=055005">
	</picture>
</a>
<hr width="80%"></div>
<!-- ------------------------- END : Bottom Panel ------------------------- --></div>
